from collections import UserList
import os

from auth import login_required, bp as auth_bp
from deck import deck, bp as deck_bp
from flask import Flask, render_template, session


def create_app(test_config=None):
    # create and configure the app
    app = Flask(__name__, instance_relative_config=True)
    app.config.from_mapping(
        SECRET_KEY='dev',
        DATABASE=os.path.join(app.instance_path, 'flaskr.sqlite'),
    )                                                                # = kaj naj tu piše?

    if test_config is None:
        # load the instance config, if it exists, when not testing
        app.config.from_pyfile('config.py', silent=True)
    else:
        # load the test config if passed in
        app.config.from_mapping(test_config)

    # ensure the instance folder exists
    try:
        os.makedirs(app.instance_path)
    except OSError:
        pass

    # a simple page that says hello

    @app.route('/')
    @login_required
    def index():
        return 'redirecting' # meče skoz nazaj na login TODO

    @app.route('/deck', methods=["GET", "POST"])
    #@login_required
    def deck():
        if 'user_id' in session:
            user_id = session['user_id']
            username = session['username']
            return render_template("deck/index.html", username=username)
        else:
            return index()
    
    @app.route('/logout')
    def logout():
        session.pop("user_id", None)
        return index()


    #app.register_blueprint(bp) # ??
    
    app.register_blueprint(auth_bp)
    app.register_blueprint(deck_bp)
    app.add_url_rule('/', endpoint='index')

    return app


app = create_app()
app.run(debug=True, host="0.0.0.0")